@@ -157,8 +157,20 @@ class Task(object):
         return objects.Task.get(task_id)
 
     @staticmethod
-    def get_detailed(task_id):
-        return objects.Task.get_detailed(task_id)
+    def get_detailed(task_id, extended_results=False):
+        """Get detailed task data.
+
+        :param task_id: str task UUID
+        :param extended_results: whether to return task data as dict
+                                 with extended results
+        :returns: rally.common.db.sqlalchemy.models.Task
+        :returns: dict
+        """
+        task = objects.Task.get_detailed(task_id)
+        if task and extended_results:
+            task = dict(task)
+            task["results"] = objects.Task.extend_results(task["results"])
+        return task
 
     @classmethod
     def render_template(cls, task_template, template_dir="./", **kwargs):
@@ -359,9 +371,10 @@ class Verification(object):
     @classmethod
     def verify(cls, deployment, set_name="", regex=None, tests_file=None,
                tempest_config=None, expected_failures=None, system_wide=False,
-               concur=0):
+               concur=0, failing=False):
         """Start verification.
 
+        :param deployment: UUID or name of a deployment
         :param deployment: UUID or name of a deployment
         :param set_name: Name of a Tempest test set
         :param regex: Regular expression of test
@@ -376,8 +389,11 @@ class Verification(object):
                             env when running the tests
         :param concur: How many processes to use to run Tempest tests.
                        The default value (0) auto-detects CPU count
+        :param failing: Re-run tests that failed during the last
+                        execution
         :returns: Verification object
         """
+
         deployment_uuid = objects.Deployment.get(deployment)["uuid"]
         verification = objects.Verification(deployment_uuid=deployment_uuid)
         verifier = tempest.Tempest(deployment_uuid,
@@ -386,6 +402,11 @@ class Verification(object):
                                    system_wide=system_wide)
 
         if not verifier.is_installed():
+            LOG.warning("Installation of Tempest will be deprecated and "
+                        "removed in the future when executing the `rally "
+                        "verify start` command. To install Tempest please "
+                        "start to use the `rally verify install` command "
+                        "before `rally verify start`.")
             LOG.info(_("Tempest is not installed "
                        "for the specified deployment."))
             LOG.info(_("Installing Tempest "
@@ -395,7 +416,8 @@ class Verification(object):
         LOG.info("Starting verification of deployment: %s" % deployment_uuid)
         verification.set_running()
         verifier.verify(set_name=set_name, regex=regex, tests_file=tests_file,
-                        expected_failures=expected_failures, concur=concur)
+                        expected_failures=expected_failures, concur=concur,
+                        failing=failing)
 
         return verification
 
