@@ -44,6 +44,9 @@ class QuotaMixin(SynchronizedDeletion):
     def id(self):
         return self.raw_resource
 
+    def name(self):
+        return None
+
     def delete(self):
         self._manager().delete(self.raw_resource)
 
@@ -98,7 +101,9 @@ class NovaServer(base.ResourceManager):
 
 @base.resource("nova", "floating_ips", order=next(_nova_order))
 class NovaFloatingIPs(SynchronizedDeletion, base.ResourceManager):
-    pass
+
+    def name(self):
+        return None
 
 
 @base.resource("nova", "keypairs", order=next(_nova_order))
@@ -127,6 +132,9 @@ class NovaFloatingIpsBulk(SynchronizedDeletion, base.ResourceManager):
     def id(self):
         return self.raw_resource.address
 
+    def name(self):
+        return None
+
     def list(self):
         return [floating_ip for floating_ip in self._manager().list()
                 if utils.name_matches_object(floating_ip.pool,
@@ -137,6 +145,9 @@ class NovaFloatingIpsBulk(SynchronizedDeletion, base.ResourceManager):
                admin_required=True, tenant_resource=True)
 class NovaNetworks(SynchronizedDeletion, base.ResourceManager):
 
+    def name(self):
+        return self.raw_resource.label
+
     def list(self):
         # NOTE(stpierre): any plugin can create a nova network via the
         # network wrapper, and that network's name will be created
@@ -209,6 +220,9 @@ class NeutronMixin(SynchronizedDeletion, base.ResourceManager):
     def id(self):
         return self.raw_resource["id"]
 
+    def name(self):
+        return self.raw_resource["name"]
+
     def delete(self):
         delete_method = getattr(self._manager(), "delete_%s" % self._resource)
         delete_method(self.id())
@@ -470,28 +484,72 @@ _designate_order = get_order(900)
 
 class DesignateResource(SynchronizedDeletion, base.ResourceManager):
     def _manager(self):
-        # NOTE: service name contains version, so we should split them
-        service_name, version = self._service.split("_v")
-        return getattr(getattr(self.user, service_name)(version),
+        # Map resource names to api / client version
+        resource_versions = {
+            "domains": "1",
+            "servers": "1",
+            "recordsets": 2,
+            "zones": "2"
+        }
+        version = resource_versions[self._resource]
+        return getattr(getattr(self.user, self._service)(version),
                        self._resource)
 
+    def _walk_pages(self, func, *args, **kwargs):
+        """Generator that keeps fetching pages until there's none left."""
+        marker = None
 
-@base.resource("designate_v1", "domains", order=next(_designate_order))
+        while True:
+            items = func(marker=marker, limit=100, *args, **kwargs)
+            if not items:
+                break
+            for item in items:
+                yield item
+            marker = items[-1]["id"]
+
+
+@base.resource("designate", "domains", order=next(_designate_order))
 class DesignateDomain(DesignateResource):
     pass
 
 
-@base.resource("designate_v2", "zones", order=next(_designate_order))
-class DesignateZones(DesignateResource):
-    pass
-
-
-@base.resource("designate_v1", "servers", order=next(_designate_order),
+@base.resource("designate", "servers", order=next(_designate_order),
                admin_required=True, perform_for_admin_only=True)
 class DesignateServer(DesignateResource):
     pass
 
 
+@base.resource("designate", "recordsets", order=next(_designate_order),
+               tenant_resource=True)
+class DesignateRecordSets(DesignateResource):
+    def _client(self):
+        # Map resource names to api / client version
+        resource_versions = {
+            "domains": "1",
+            "servers": "1",
+            "recordsets": 2,
+            "zones": "2"
+        }
+        version = resource_versions[self._resource]
+        return getattr(self.user, self._service)(version)
+
+    def list(self):
+        criterion = {"name": "s_rally_*"}
+        for zone in self._walk_pages(self._client().zones.list,
+                                     criterion=criterion):
+            for recordset in self._walk_pages(self._client().recordsets.list,
+                                              zone["id"]):
+                yield recordset
+
+
+@base.resource("designate", "zones", order=next(_designate_order),
+               tenant_resource=True)
+class DesignateZones(DesignateResource):
+    def list(self):
+        criterion = {"name": "s_rally_*"}
+        return self._walk_pages(self._manager().list, criterion=criterion)
+
+
 # SWIFT
 
 _swift_order = get_order(1000)
@@ -506,6 +564,12 @@ class SwiftMixin(SynchronizedDeletion, base.ResourceManager):
     def id(self):
         return self.raw_resource
 
+    def name(self):
+        # NOTE(stpierre): raw_resource is a list of either [container
+        # name, object name] (as in SwiftObject) or just [container
+        # name] (as in SwiftContainer).
+        return self.raw_resource[-1]
+
     def delete(self):
         delete_method = getattr(self._manager(), "delete_%s" % self._resource)
         # NOTE(weiwu): *self.raw_resource is required because for deleting
@@ -592,6 +656,9 @@ class FuelEnvironment(base.ResourceManager):
     def id(self):
         return self.raw_resource["id"]
 
+    def name(self):
+        return self.raw_resource["name"]
+
     def is_deleted(self):
         return not self._manager().get(self.id())
 
