@@ -17,41 +17,13 @@ from boto import exception as boto_exception
 import mock
 from neutronclient.common import exceptions as neutron_exceptions
 
-from rally.common.plugin import discover
 from rally.common import utils
-from rally.plugins.openstack.cleanup import base
 from rally.plugins.openstack.cleanup import resources
 from tests.unit import test
 
 BASE = "rally.plugins.openstack.cleanup.resources"
 
 
-class AllResourceManagerTestCase(test.TestCase):
-
-    def test_res_manager_special_field(self):
-
-        for res_mgr in discover.itersubclasses(base.ResourceManager):
-            manager_name = "%s.%s" % (res_mgr.__module__, res_mgr.__name__)
-
-            fields = filter(lambda x: not x.startswith("__"), dir(res_mgr))
-
-            available_opts = set([
-                "_admin_required", "_perform_for_admin_only",
-                "_tenant_resource", "_service", "_resource", "_order",
-                "_max_attempts", "_timeout", "_interval", "_threads",
-                "_manager", "id", "is_deleted", "delete", "list",
-                "supports_extension"
-            ])
-
-            extra_opts = set(fields) - available_opts
-
-            self.assertFalse(
-                extra_opts,
-                ("ResourceManager %(name)s contains extra fields: %(opts)s."
-                 " Remove them to pass this test")
-                % {"name": manager_name, "opts": ", ".join(extra_opts)})
-
-
 class SynchronizedDeletionTestCase(test.TestCase):
 
     def test_is_deleted(self):
@@ -65,6 +37,11 @@ class QuotaMixinTestCase(test.TestCase):
         quota.raw_resource = mock.MagicMock()
         self.assertEqual(quota.raw_resource, quota.id())
 
+    def test_name(self):
+        quota = resources.QuotaMixin()
+        quota.raw_resource = mock.MagicMock()
+        self.assertIsNone(quota.name())
+
     def test_delete(self):
         quota = resources.QuotaMixin()
         mock_manager = mock.MagicMock()
@@ -129,6 +106,14 @@ class NovaServerTestCase(test.TestCase):
             server.raw_resource.id)
 
 
+class NovaFloatingIPsTestCase(test.TestCase):
+
+    def test_name(self):
+        fips = resources.NovaFloatingIPs()
+        fips.raw_resource = mock.MagicMock()
+        self.assertIsNone(fips.name())
+
+
 class NovaSecurityGroupTestCase(test.TestCase):
 
     @mock.patch("%s.base.ResourceManager._manager" % BASE)
@@ -150,6 +135,11 @@ class NovaFloatingIpsBulkTestCase(test.TestCase):
         ip_range.raw_resource = mock.MagicMock()
         self.assertEqual(ip_range.raw_resource.address, ip_range.id())
 
+    def test_name(self):
+        fips = resources.NovaFloatingIpsBulk()
+        fips.raw_resource = mock.MagicMock()
+        self.assertIsNone(fips.name())
+
     @mock.patch("%s.base.ResourceManager._manager" % BASE)
     @mock.patch("rally.common.utils.name_matches_object")
     def test_list(self, mock_name_matches_object,
@@ -167,6 +157,11 @@ class NovaFloatingIpsBulkTestCase(test.TestCase):
 
 class NovaNetworksTestCase(test.TestCase):
 
+    def test_name(self):
+        network = resources.NovaNetworks()
+        network.raw_resource = mock.MagicMock()
+        self.assertEqual(network.raw_resource.label, network.name())
+
     @mock.patch("rally.common.plugin.discover.itersubclasses")
     def test_list(self, mock_itersubclasses):
         nova_nets = resources.NovaNetworks()
@@ -281,6 +276,11 @@ class NeutronMixinTestCase(test.TestCase):
         neut.raw_resource = {"id": "test"}
         self.assertEqual("test", neut.id())
 
+    def test_name(self):
+        neutron = self.get_neutron_mixin()
+        neutron.raw_resource = {"id": "test_id", "name": "test_name"}
+        self.assertEqual("test_name", neutron.name())
+
     def test_delete(self):
         neut = self.get_neutron_mixin()
         neut.user = mock.MagicMock()
@@ -501,6 +501,11 @@ class SwiftMixinTestCase(test.TestCase):
         swift_mixin.raw_resource = mock.MagicMock()
         self.assertEqual(swift_mixin.raw_resource, swift_mixin.id())
 
+    def test_name(self):
+        swift = self.get_swift_mixin()
+        swift.raw_resource = ["name1", "name2"]
+        self.assertEqual("name2", swift.name())
+
     def test_delete(self):
         swift_mixin = self.get_swift_mixin()
         swift_mixin.user = mock.MagicMock()
@@ -614,6 +619,11 @@ class FuelEnvironmentTestCase(test.TestCase):
         fres.raw_resource = {"id": 42, "name": "chavez"}
         self.assertEqual(42, fres.id())
 
+    def test_name(self):
+        fuel = resources.FuelEnvironment()
+        fuel.raw_resource = {"id": "test_id", "name": "test_name"}
+        self.assertEqual("test_name", fuel.name())
+
     @mock.patch("%s.FuelEnvironment._manager" % BASE)
     def test_is_deleted(self, mock__manager):
         mock__manager.return_value.get.return_value = None
