@@ -256,6 +256,24 @@ class TaskAPITestCase(test.TestCase):
         mock_task_delete.assert_called_once_with(
             self.task_uuid, status=None)
 
+    @mock.patch("rally.api.objects.Task")
+    def test_get_detailed(self, mock_task):
+        mock_task.get_detailed.return_value = "detailed_task_data"
+        self.assertEqual("detailed_task_data",
+                         api.Task.get_detailed("task_uuid"))
+        mock_task.get_detailed.assert_called_once_with("task_uuid")
+
+    @mock.patch("rally.api.objects.Task")
+    def test_get_detailed_with_extended_results(self, mock_task):
+        mock_task.get_detailed.return_value = (("uuid", "foo_uuid"),
+                                               ("results", "raw_results"))
+        mock_task.extend_results.return_value = "extended_results"
+        self.assertEqual({"uuid": "foo_uuid", "results": "extended_results"},
+                         api.Task.get_detailed("foo_uuid",
+                                               extended_results=True))
+        mock_task.get_detailed.assert_called_once_with("foo_uuid")
+        mock_task.extend_results.assert_called_once_with("raw_results")
+
 
 class BaseDeploymentTestCase(test.TestCase):
     def setUp(self):
@@ -410,7 +428,7 @@ class VerificationAPITestCase(BaseDeploymentTestCase):
         self.tempest.is_installed.assert_called_once_with()
         self.tempest.verify.assert_called_once_with(
             set_name="smoke", regex=None, tests_file=None,
-            expected_failures=None, concur=0)
+            expected_failures=None, concur=0, failing=False)
 
     @mock.patch("rally.api.objects.Deployment.get")
     @mock.patch("rally.api.objects.Verification")
@@ -424,12 +442,11 @@ class VerificationAPITestCase(BaseDeploymentTestCase):
         api.Verification.verify(
             self.deployment_uuid, set_name="smoke",
             regex=None, tests_file=None, tempest_config=None)
-
         self.tempest.is_installed.assert_called_once_with()
         self.tempest.install.assert_called_once_with()
         self.tempest.verify.assert_called_once_with(
             set_name="smoke", regex=None, tests_file=None,
-            expected_failures=None, concur=0)
+            expected_failures=None, concur=0, failing=False)
 
     @mock.patch("os.path.exists", return_value=True)
     @mock.patch("rally.api.objects.Deployment.get")
@@ -443,11 +460,11 @@ class VerificationAPITestCase(BaseDeploymentTestCase):
         tests_file = "/path/to/tests/file"
         api.Verification.verify(
             self.deployment_uuid, set_name="", regex=None,
-            tests_file=tests_file, tempest_config=None)
+            tests_file=tests_file, tempest_config=None, failing=False)
 
         self.tempest.verify.assert_called_once_with(
             set_name="", regex=None, tests_file=tests_file,
-            expected_failures=None, concur=0)
+            expected_failures=None, concur=0, failing=False)
 
     @mock.patch("rally.common.objects.Deployment.get")
     @mock.patch("rally.api.objects.Verification")
